/*
  This file should be executed to create the tables. It contains the constraints
  for foreign keys and composite keys.

  This file is going to be used to generate the JPA stuffs.

  Changes to this file can come at any time.
 */

CREATE TABLE IF NOT EXISTS student (
  id                      SERIAL PRIMARY KEY,
  user_name               VARCHAR (32) NOT NULL UNIQUE,
  pwd                     VARCHAR (256) NOT NULL,

  /* name */
  name_first              VARCHAR (32) NOT NULL,
  name_last               VARCHAR (32) NOT NULL,

  class                   VARCHAR (32) /* This could be a foreign key :-) */

  /* address */
  /*
  address_country         VARCHAR (32) NOT NULL,
  address_city            VARCHAR (32) NOT NULL,
  address_street          VARCHAR (32) NOT NULL,
  address_postal_code     VARCHAR (32) NOT NULL,

  birthday                DATE NOT NULL
  */
);

CREATE TABLE IF NOT EXISTS staff_type (
  id                      SERIAL PRIMARY KEY,
  name                    VARCHAR (32) UNIQUE
);


/* Add staff types to database ************************************************/
INSERT INTO staff_type (id, name) VALUES (0, 'NONE'); /* We need to have the
                                                         zero:th value be none
                                                         so we don't get caught
                                                         in the 'null trap'.
                                                         */
INSERT INTO staff_type (name) VALUES ('Admin');
INSERT INTO staff_type (name) VALUES ('Teacher');
/******************************************************************************/

CREATE TABLE IF NOT EXISTS staff (
  id                      SERIAL PRIMARY KEY,
  user_name               VARCHAR (32)  NOT NULL UNIQUE,
  pwd                     VARCHAR (256) NOT NULL,

  staff_type              BIGINT,

  /* name */
  name_first              VARCHAR (32) NOT NULL,
  name_last               VARCHAR (32) NOT NULL,
  /*
  employee_nr             VARCHAR (32) NOT NULL UNIQUE,
  */
  CONSTRAINT staff_type_kf  FOREIGN KEY (staff_type)
                            REFERENCES staff_type (id)
);



CREATE TABLE IF NOT EXISTS course (
  id                      SERIAL PRIMARY KEY,

  name                    VARCHAR (30) UNIQUE,
  description             TEXT
);

CREATE TABLE IF NOT EXISTS lecture (
  course BIGINT           NOT NULL,
  start_time              TIME NOT NULL,
  end_time                TIME NOT NULL,

  CONSTRAINT course_fk    FOREIGN KEY (course)
                          REFERENCES course (id),

  CONSTRAINT lecture_pk   PRIMARY KEY (course, start_time, end_time)
);

CREATE TABLE IF NOT EXISTS teaches (
  course BIGINT           NOT NULL,
  staff BIGINT            NOT NULL,

  CONSTRAINT course_fk    FOREIGN KEY (course)
                          REFERENCES course (id),

  CONSTRAINT staff_fk     FOREIGN KEY (staff)
                          REFERENCES course (id),

  CONSTRAINT teaches_pk   PRIMARY KEY (course, staff)
);

CREATE TABLE IF NOT EXISTS student_attendance (
  lecture_course          BIGINT NOT NULL,
  lecture_start_time      TIME NOT NULL,
  lecture_end_time        TIME NOT NULL,


  student                 BIGINT NOT NULL,

  late_time               INTEGER,

  CONSTRAINT lecture_fk   FOREIGN KEY (lecture_course,
                                      lecture_start_time,
                                      lecture_end_time)
                          REFERENCES lecture (course,
                                              start_time,
                                              end_time),

  CONSTRAINT student_fk   FOREIGN KEY (student)
                          REFERENCES student (id),

  CONSTRAINT student_attendance_pk PRIMARY KEY (lecture_course,
                                                lecture_start_time,
                                                lecture_end_time,
                                                student)

);

